/*
   This file maintains the "console gui".

   You should not modify anything in this file (unless
   you want to make the "gui" more interesting).

   The roomDisplay() function below is a thread function.
   This function defines a thread that maintains the
   console gui. This thread uses the curses console library
   to draw representations of "rooms" and representations
   of threads that are in this "rooms.

   There is an array customers[] (declared in Hw2.c) that
   holds pointers to customer_t data structures, one structure
   for each running customer thread. Each structure holds a
   customer id number, a customer state, and a run time for
   that customer's thread. This gui walks through that array,
   and for each customer structure it finds, it draws a
   representation of that customer's thread in the appropriate
   "room" of the gui (the state of the thread determines the
   appropriate room).
*/
#include "curses.h"

// set the interval of time (in seconds) between console updates
#define UPDATE_INTERVAL 1

void* roomDisplay(void* threadParam)
{
   char entryRoom[]  = "Entry Room (strike any key to create a new customer) ======="; // 60 chars
   char diningRoom[] = "Dining Room ================================================";
   char exitRoom[]   = "Exit Room ==================================================";
   char customerString[9];

   int stateCounters[3];  // count the number of customers in each state

   // write the three "room divider" strings
   mvprintw( 0, 0, entryRoom);
   mvprintw(15, 0, diningRoom);
   mvprintw(30, 0, exitRoom);

   while(1)  // repeatedly update the console screen buffer
   {
      int i;

      // erase what we wrote into the console screen buffer in the last refresh
      mvprintw( 5, 0,  "                                                            ");
      mvprintw( 5,60,  "                                                            ");
      mvprintw(20, 0,  "                                                            ");
      mvprintw(20,60,  "                                                            ");
      mvprintw(35, 0,  "                                                            ");
      mvprintw(35,60,  "                                                            ");

      // walk the customer array, looking for customers to print out.
      stateCounters[0] = 0;
      stateCounters[1] = 0;  // count the number of customers in each state
      stateCounters[2] = 0;
      for (i = 0; i < CUSTOMERS; i++)
      {
         if (customers[i])
         {

            int x = 8 * stateCounters[ customers[i]->state ];
            int y = 5 + (15 * (customers[i]->state));
            stateCounters[ customers[i]->state ] += 1;
            // create an output string containing id number and time remaining in dining state
            sprintf(customerString, "%s(%d)", customers[i]->id, customers[i]->time);
            move(y,x);
            printw(customerString);
         }
      }

      move(0, 0);
      refresh();  // update the console screen
      sleep(UPDATE_INTERVAL);
   }
   return 0;
}//roomDisplay()